==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/messages/es/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Confirmar</strong> Acción',
    '<strong>Latest</strong> updates' => '<strong>Últimas</strong> actualizaciones',
    '<strong>Mail</strong> summary' => '<strong>Resumen</strong> de Correo',
    'Account settings' => 'Configuración de la cuenta',
    'Actions' => 'Acciones',
    'Add:' => 'Añadir:',
    'Administration' => 'Administración',
    'All' => 'Todo',
    'Allow' => 'Permitir',
    'An error occurred while handling your last action. (Handler not found).' => 'Se ha producido un error al manejar la última acción. (No se encuentra el manejador).',
    'An unexpected error occurred while loading the search result.' => 'Se ha producido un error inesperado al cargar el resultado de la búsqueda.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Ocurrió un error inesperado. Si esto sigue sucediendo, póngase en contacto con un administrador del sitio.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Se ha producido un error inesperado en el servidor. Si esto sigue sucediendo, póngase en contacto con un administrador del sitio.',
    'An unknown error occurred while uploading.' => 'Se ha producido un error desconocido al cargar.',
    'An unknown error occurred while uploading. Hint: check your upload_max_filesize and post_max_size php settings.' => 'Se ha producido un error desconocido al cargar. Consejo: compruebe la configuración de PHP para upload_max_filesize y post_max_size',
    'Back' => 'Atrás',
    'Back to dashboard' => 'Volver al Panel de Control',
    'Cancel' => 'Cancelar',
    'Choose language:' => 'Escoja idioma:',
    'Close' => 'Cerrar',
    'Collapse' => 'Cerrar',
    'Confirm' => 'Confirmar',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => '¡La fuente de Contenido del Complemento debe ser una instancia de HActiveRecordContent o HActiveRecordContentAddon!',
    'Copy to clipboard' => 'Copiar al portapapeles',
    'Could not find content of addon!' => '¡No se pudo encontrar el contenido del complemento!',
    'Could not find requested page.' => 'No se ha encontrado la página solicitada',
    'Default' => 'Por Defecto',
    'Delete' => 'Borrar',
    'Deny' => 'Denegar',
    'Do you really want to perform this action?' => '¿Realmente desea ejecutar esta acción?',
    'Edit' => 'Editar',
    'Error' => 'Error',
    'Error while running your last action (Invalid request method).' => 'Error al ejecutar la última acción (método de solicitud no válido).',
    'Error:' => 'Error:',
    'Expand' => 'Ampliar',
    'Export' => 'Exportar',
    'Info:' => 'Info:',
    'Invalid request method!' => 'Método de la petición no válido',
    'It looks like you may have taken the wrong turn.' => 'Parece que puede haber tomado el camino equivocado.',
    'Language' => 'Idioma',
    'Loading...' => 'Cargando...',
    'Login' => 'Iniciar sesión',
    'Logo of {appName}' => 'Logo de {appName}',
    'Logout' => 'Salir',
    'Menu' => 'Menú',
    'Module is not enabled on this content container!' => 'El módulo no está habilitado en este contenedor de contenido!',
    'My profile' => 'Mi perfil',
    'New profile image' => 'Nueva imagen de perfil',
    'Next' => 'Siguiente',
    'No error information given.' => 'No se dio información.',
    'Oooops...' => 'Oooops...',
    'Open' => 'Abrir',
    'Please type at least 3 characters' => 'Por favor escriba al menos 3 caracteres',
    'Please type at least {count} characters' => 'Por favor, teclee al menos {count} caracteres',
    'Powered by {name}' => 'Un sistema de {name}',
    'Profile dropdown' => 'Perfil desplegable',
    'Profile picture of {displayName}' => 'Imagen de perfil de {displayName}',
    'Save' => 'Guardar',
    'Saved' => 'Guardado',
    'Search' => 'Buscar',
    'Select Me' => 'Seleccione',
    'Show less' => 'Mostrar menos',
    'Show more' => 'Mostrar más',
    'Some files could not be uploaded:' => 'Algunos archivos no se pueden cargar:',
    'Stop impersonation' => 'Impedir la suplantación',
    'Text could not be copied to clipboard' => 'El texto no se ha podido copiar al portapapeles',
    'Text has been copied to clipboard' => 'El texto se ha copiado al portapapeles',
    'The date has to be in the past.' => 'La fecha tiene que ser en el pasado.',
    'The file has been deleted.' => 'Este archivo ha sido borrado.',
    'The requested resource could not be found.' => 'El recurso solicitado no pudo ser encontrado.',
    'The space has been archived.' => 'Este espacio ha sido archivado.',
    'The space has been unarchived.' => 'Este espacio ha sido desarchivado.',
    'Time Zone' => 'Zona horaria',
    'Toggle comment menu' => 'Conmutar el menú de comentarios',
    'Toggle panel menu' => 'Conmutar el menú de panel',
    'Toggle post menu' => 'Conmutar el menú de entrada',
    'Toggle stream entry menu' => 'Conmutar el menú de actividad',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Hay cambios no guardados, ¿realmente quiere salir?',
    'Unsubscribe' => 'Anular la suscripción',
    'Upload' => 'Subir',
    'Upload file' => 'Cargar archivo',
    'You are not allowed to run this action.' => 'No estás autorizado para realizar esta acción.',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
];

==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/messages/es/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Confirmar</strong> Acción',
    '<strong>Latest</strong> updates' => '<strong>Últimas</strong> actualizaciones',
    '<strong>Mail</strong> summary' => '<strong>Resumen</strong> de Correo',
    'Actions' => 'Acciones',
    'Add:' => 'Añadir:',
    'Administration' => 'Administración',
    'All' => 'Todo',
    'Allow' => 'Permitir',
    'Allow content from external source' => 'Permitir contenido de una fuente externa',
    'Always allow content from this provider!' => 'Permitir siempre el contenido de este proveedor',
    'An error occurred while handling your last action. (Handler not found).' => 'Se ha producido un error al manejar la última acción. (No se encuentra el manejador).',
    'An unexpected error occurred while loading the search result.' => 'Se ha producido un error inesperado al cargar el resultado de la búsqueda.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Ocurrió un error inesperado. Si esto sigue sucediendo, póngase en contacto con un administrador del sitio.',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => 'Se ha producido un error inesperado. Por favor compruebe si su fichero excede el límite de {maxUploadSize}.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Se ha producido un error inesperado en el servidor. Si esto sigue sucediendo, póngase en contacto con un administrador del sitio.',
    'Back' => 'Atrás',
    'Back to dashboard' => 'Volver al Panel de Control',
    'Cancel' => 'Cancelar',
    'Choose language:' => 'Escoja idioma:',
    'Close' => 'Cerrar',
    'Collapse' => 'Cerrar',
    'Confirm' => 'Confirmar',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => '¡La fuente de Contenido del Complemento debe ser una instancia de HActiveRecordContent o HActiveRecordContentAddon!',
    'Copy to clipboard' => 'Copiar al portapapeles',
    'Could not find content of addon!' => '¡No se pudo encontrar el contenido del complemento!',
    'Could not find requested page.' => 'No se ha encontrado la página solicitada',
    'Default' => 'Por Defecto',
    'Delete' => 'Borrar',
    'Deny' => 'Denegar',
    'Do you really want to perform this action?' => '¿Realmente desea ejecutar esta acción?',
    'Do you want to enable content from \'{urlPrefix}\'?' => '¿Quieres permitir el contenido de \'{urlPrefix}\'?',
    'Edit' => 'Editar',
    'Error' => 'Error',
    'Error while running your last action (Invalid request method).' => 'Error al ejecutar la última acción (método de solicitud no válido).',
    'Error:' => 'Error:',
    'Expand' => 'Ampliar',
    'Export' => 'Exportar',
    'Info:' => 'Info:',
    'Invalid request method!' => 'Método de la petición no válido',
    'It looks like you may have taken the wrong turn.' => 'Parece que puede haber tomado el camino equivocado.',
    'Language' => 'Idioma',
    'Loading...' => 'Cargando...',
    'Login' => 'Iniciar sesión',
    'Logo of {appName}' => 'Logo de {appName}',
    'Logout' => 'Salir',
    'Menu' => 'Menú',
    'Module is not enabled on this content container!' => 'El módulo no está habilitado en este contenedor de contenido!',
    'My Profile' => 'Mi perfil',
    'New profile image' => 'Nueva imagen de perfil',
    'Next' => 'Siguiente',
    'No error information given.' => 'No se dio información.',
    'Oooops...' => 'Oooops...',
    'Open' => 'Abrir',
    'Please type at least 3 characters' => 'Por favor escriba al menos 3 caracteres',
    'Please type at least {count} characters' => 'Por favor, teclee al menos {count} caracteres',
    'Powered by {name}' => 'Un sistema de {name}',
    'Profile dropdown' => 'Perfil desplegable',
    'Profile picture of {displayName}' => 'Imagen de perfil de {displayName}',
    'Save' => 'Guardar',
    'Saved' => 'Guardado',
    'Search' => 'Buscar',
    'Search...' => 'Buscar...',
    'Select Me' => 'Seleccione',
    'Settings' => 'Ajustes',
    'Show less' => 'Mostrar menos',
    'Show more' => 'Mostrar más',
    'Some files could not be uploaded:' => 'Algunos archivos no se pueden cargar:',
    'Stop impersonation' => 'Impedir la suplantación',
    'Text could not be copied to clipboard' => 'El texto no se ha podido copiar al portapapeles',
    'Text has been copied to clipboard' => 'El texto se ha copiado al portapapeles',
    'The date has to be in the past.' => 'La fecha tiene que ser en el pasado.',
    'The file has been deleted.' => 'Este archivo ha sido borrado.',
    'The requested resource could not be found.' => 'El recurso solicitado no pudo ser encontrado.',
    'The space has been archived.' => 'Este espacio ha sido archivado.',
    'The space has been unarchived.' => 'Este espacio ha sido desarchivado.',
    'Time Zone' => 'Zona horaria',
    'Toggle comment menu' => 'Conmutar el menú de comentarios',
    'Toggle panel menu' => 'Conmutar el menú de panel',
    'Toggle post menu' => 'Conmutar el menú de entrada',
    'Toggle stream entry menu' => 'Conmutar el menú de actividad',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Hay cambios no guardados, ¿realmente quiere salir?',
    'Unsubscribe' => 'Anular la suscripción',
    'Upload' => 'Subir',
    'Upload file' => 'Cargar archivo',
    'You are not allowed to run this action.' => 'No estás autorizado para realizar esta acción.',
    'verify your upload_max_filesize and post_max_size php settings.' => 'verifique su configuración de PHP upload_max_filesize y post_max_size',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '{attribute} está vacío. La función del sistema para rellenar valores vacíos ha devuelto un valor inválido. Por favor vuelva a intentarlo o contacte con su administrador.',
    '{attribute} must be a string (UUID) or null; {type} given.' => '{attribute} debería ser una cadena (UUID) o un valor nulo, pero se ha proporcionado un valor de tipo {type}.',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '{attribute} debe ser un UUID o nulo. UUID tiene el formato "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", donde X = [a-fA-F0-9] y tanto llaves como guiones son opcionales.',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    'No results' => '',
    'Show all results' => '',
];
